pub struct NodePath {
pub indices: Vec<usize>,
}Expand description
Represents a path through the MCTS tree
A path is a sequence of indices that can be used to navigate from the root node to a specific node in the tree.
Fields
indices: Vec<usize>Indices of children to follow from the root
Implementations